@@ -1,13 +1,13 @@
 import asyncio
-import importlib
 import json
 import os
+import shutil
 import sys
 from pathlib import Path
 from typing import List
 
-import pkg_resources  # type: ignore
-
+import pkg_resources
+import requests  # type: ignore
 import tomli
 import uvicorn  # type: ignore
 from fastapi import FastAPI, WebSocket
@@ -16,11 +16,7 @@ from fastapi.staticfiles import StaticFiles
 
 from zeno.classes import (
     MetricKey,
-    PipelineIdFilter,
-    PipelineInit,
-    PipelineProjection,
-    PipelineRegionLabeler,
-    PipelineReset,
+    MirrorProject,
     Report,
     Slice,
     StatusResponse,
@@ -30,6 +26,9 @@ from zeno.classes import (
 )
 from zeno.zeno import Zeno
 
+VIEW_MAP_URL = "https://raw.githubusercontent.com/zeno-ml/instance-views/main/"
+VIEWS_MAP_JSON = "views.json"
+
 
 def main():
 
@@ -74,24 +73,40 @@ def main():
     toml_path = os.path.dirname(os.path.abspath(sys.argv[1]))
 
     if "view" not in args:
-        print(
-            "ERROR: Must have 'view' entry which is a valid and installed"
-            + "Python Zeno view package:"
+        print("ERROR: Must have 'view' entry")
+        sys.exit(1)
+
+    if "cache_path" not in args:
+        args["cache_path"] = Path(
+            os.path.realpath(os.path.join(toml_path, "./.zeno_cache/"))
         )
-        sys.exit(1)
+    else:
+        args["cache_path"] = Path(
+            os.path.realpath(os.path.join(toml_path, args["cache_path"]))
+        )
+    os.makedirs(args["cache_path"], exist_ok=True)
 
+    # Try to get view from GitHub List, if not try to read from path and copy it.
+    views_res = requests.get(VIEW_MAP_URL + VIEWS_MAP_JSON)
+    views = views_res.json()
+    view_dest_path = Path(os.path.join(args["cache_path"], "view.mjs"))
     try:
-        args["view"] = args["view"].replace("-", "_")
-        mod = importlib.import_module(args["view"])
-    except ModuleNotFoundError:
-        print("ERROR: " + args["view"] + " is not a valid python package")
-        sys.exit(1)
-
-    if not mod.path:
-        print("ERROR: View does not export a valid path variable.")
-        sys.exit(1)
-
-    args["view"] = mod.path
+        url = VIEW_MAP_URL + views[args["view"]]
+        with open(view_dest_path, "wb") as out_file:
+            content = requests.get(url, stream=True).content
+            out_file.write(content)
+    except KeyError:
+        view_path = Path(os.path.realpath(os.path.join(toml_path, args["view"])))
+        if view_path.is_file():
+            if view_dest_path.is_file():
+                os.remove(view_dest_path)
+            shutil.copyfile(view_path, view_dest_path)
+        else:
+            print(
+                "ERROR: View not found in list or relative path. See available views",
+                "at https://github.com/zeno-ml/instance-views/blob/main/views.json",
+            )
+            sys.exit(1)
 
     if "metadata" not in args:
         print("ERROR: Must have 'metadata' entry which must be a CSV or Parquet file.")
@@ -101,7 +116,9 @@ def main():
             os.path.realpath(os.path.join(toml_path, args["metadata"]))
         )
 
-    if "tests" not in args or not os.path.exists(args["tests"]):
+    if "tests" not in args or not os.path.exists(
+        os.path.realpath(os.path.join(toml_path, args["tests"]))
+    ):
         print("WARNING: No 'tests' directory found.")
         args["tests"] = None
     else:
@@ -152,18 +169,12 @@ def main():
     if "port" not in args:
         args["port"] = 8000
 
+    if "host" not in args:
+        args["host"] = "localhost"
+
     if "batch_size" not in args:
         args["batch_size"] = 1
 
-    if "cache_path" not in args:
-        args["cache_path"] = Path(
-            os.path.realpath(os.path.join(toml_path, "./.zeno_cache/"))
-        )
-    else:
-        args["cache_path"] = Path(
-            os.path.realpath(os.path.join(toml_path, args["cache_path"]))
-        )
-
     run_zeno(args)
 
 
@@ -195,11 +206,6 @@ def run_zeno(args):
         StaticFiles(directory=args["cache_path"]),
         name="cache",
     )
-    app.mount(
-        "/view",
-        StaticFiles(directory=args["view"]),
-        name="view",
-    )
     app.mount("/api", api_app)
     app.mount(
         "/",
@@ -258,42 +264,26 @@ def run_zeno(args):
     def update_reports(reqs: List[Report]):
         zeno.set_reports(reqs)
 
-    @api_app.post("/pipe/reset")
-    def reset_pipeline(req: PipelineReset):
-        zeno.reset_pipeline(req.up_to_id)
-        return json.dumps({"status": True})
+    @api_app.post("/mirror/project")
+    def mirror_project(req: MirrorProject):
+        # not specified or entire data frame just use the cache
+        if req.ids is None or len(req.ids) == len(zeno.df):
+            proj = zeno.mirror.initProject(req.model, req.transform)
+        else:
+            proj = zeno.mirror.filterProject(
+                req.model, req.ids, req.transform, perplexity=req.perplexity
+            )
 
-    @api_app.post("/pipe/load")
-    def load_pipeline(req: PipelineInit):
-        js_export = zeno.load_pipeline(req.model, req.uid)
-        return json.dumps({"status": True, "data": js_export})
+        return json.dumps({"model": req.model, "data": proj})
 
-    @api_app.post("/pipe/init")
-    def init_pipeline(req: PipelineInit):
-        zeno.init_pipeline(req.model, req.uid)
-        return json.dumps({"status": True})
+    @api_app.get("/mirror/sdm")
+    def sdm():
+        return json.dumps({"data": zeno.mirror.generate_slices()})
 
-    @api_app.post("/pipe/id-filter")
-    def filter_pipeline(req: PipelineIdFilter):
-        js_export = zeno.add_id_filter_pipeline(req.ids)
-        return json.dumps({"status": True, "data": js_export})
-
-    @api_app.post("/pipe/umap")
-    def umap_pipeline(req: PipelineProjection):
-        js_export = zeno.add_umap_pipeline(req.args)
-        return json.dumps({"status": True, "data": js_export})
-
-    @api_app.post("/pipe/region-labeler")
-    def region_labeler_pipeline(req: PipelineRegionLabeler):
-        js_export = zeno.add_region_labeler_pipeline(
-            req.polygon, req.name, req.up_to_id
-        )
-        return json.dumps({"status": True, "data": js_export})
-
-    @api_app.get("/pipe/graph")
-    def get_pipeline_json():
-        js_export = zeno.get_json_pipeline()
-        return json.dumps({"status": True, "data": js_export})
+    @api_app.get("/mirror/exists/{model}")
+    def embedding_exists(model: str):
+        exists = zeno.embedding_exists(model)
+        return json.dumps({"model": model, "exists": exists})
 
     @api_app.websocket("/status")
     async def results_websocket(websocket: WebSocket):
@@ -311,4 +301,4 @@ def run_zeno(args):
                     ).json(by_alias=True)
                 )
 
-    uvicorn.run(app, host="localhost", port=args["port"])  # type: ignore
+    uvicorn.run(app, host=args["host"], port=args["port"])  # type: ignore
